@@ -1,44 +1,47 @@
 
-/***************************************************************************
-                          files.h  -  define file related functions
-                             -------------------
-    begin                : Sat Nov 10 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
 /* We want skip most of these includes when building documentation */
-#ifndef BUILD_DOCS
 
+#include "files.h"
 #include "xsldbg.h"
 #include <stdio.h>
 #include <libxml/entities.h>
 #include <libxml/tree.h>
 #include <libxml/catalog.h>
-#include <libxml/parserInternals.h>
 #include <libxml/encoding.h>    /* needed by filesTranslate, filesEncoding functions */
 #include <libxml/uri.h>    /* needed for  xmlURIUnescapeString */
 #include "debugXSL.h"
-#include "files.h"
 #include "utils.h"
 #include "options.h"
+#include <QDir>
+
+#include <unistd.h>
 #include "xsldbgthread.h"
 #ifdef WIN32
 #include <direct.h>
 #endif
 
-#endif /* BUILD_DOCS */
-
-
 /* top xml document */
 static xmlDocPtr topDocument;
 
@@ -52,10 +55,10 @@ static xmlChar filesBuffer[DEBUG_BUFFER_SIZE];
 static xsltStylesheetPtr topStylesheet;
 
 /* what is the base path for top stylesheet */
-static xmlChar *stylePathName = NULL;
+static QString stylePathName;
 
 /* what is the path for current working directory*/
-static xmlChar *workingDirPath = NULL;
+static QString workingDirPath;
 
 static arrayListPtr entityNameList = NULL;
 
@@ -75,40 +78,36 @@ static xmlChar *currentUrl = NULL;
  -------------------------------------------*/
 
 /**
- * guessStylesheetHelper:
- * @payload: valid xsltStylesheetPtr
- * @data: valid searchInfoPtr of type SEARCH_NODE
- * @name: not used
- *
  * Try to guess what the complete file/URI is. If successful the search
  *   info will be set to found and the search data will contain the
  *   file name found. We are given our payload via walkStylesheets
+ *
+ * @param payload: valid xsltStylesheetPtr
+ * @param data: valid searchInfoPtr of type SEARCH_NODE
+ * @param name: not used
+ *
  */
-static void guessStylesheetHelper(void *payload, void *data,
-                                  xmlChar * name);
+static void guessStylesheetHelper(void *payload, void *data, xmlChar * name);
 
 
 /**
- * guessStylesheetHelper2:
- * @payload: valid xmlNodePtr of the included stylesheet 
- * @data: valid searchInfoPtr of type SEARCH_NODE
- * @name: not used
- *
  * Try to guess what the complete file/URI is. If successful the search
  *   info will be set to found and the search data will contain the
  *   file name found. We are given our payload via walkIncludes
+ *
+ * @param payload: valid xmlNodePtr of the included stylesheet 
+ * @param data: valid searchInfoPtr of type SEARCH_NODE
+ * @param name: not used
+ *
  */
-static void guessStylesheetHelper2(void *payload, void *data,
-                                   xmlChar * name);
+static void guessStylesheetHelper2(void *payload, void *data, xmlChar * name);
 
 
-entityInfoPtr filesNewEntityInfo(const xmlChar * SystemID,
-                                 const xmlChar * PublicID);
+entityInfoPtr filesNewEntityInfo(const xmlChar * SystemID, const xmlChar * PublicID);
 
 void filesFreeEntityInfo(entityInfoPtr info);
 
-void filesAddEntityName(const xmlChar * SystemID,
-                        const xmlChar * PublicID);
+void filesAddEntityName(const xmlChar * SystemID, const xmlChar * PublicID);
 
 
 /* ------------------------------------- 
@@ -126,17 +125,7 @@ FILE *terminalIO;
 static char *termName = NULL;   /* what is the name of terminal we are redirected to */
 
 
-/**
- * redirectToTerminal:
- * @device: terminal to redirect i/o to , will not work under win32
- *
- * Open communications to the terminal device @device
- *
- * Returns 1 if sucessful
- *         0 otherwise
- */
-int
-openTerminal(xmlChar * device)
+int openTerminal(xmlChar * device)
 {
     int result = 0;
 
@@ -189,7 +178,7 @@ openTerminal(xmlChar * device)
                     termName = xmlMemStrdup((char *) device);
                     result = 1;
                 } else {
-                    xsldbgGenericErrorFunc(i18n("Error: Unable to open terminal %1.\n").arg((char*)termName));
+                    xsldbgGenericErrorFunc(i18n("Error: Unable to open terminal %1.\n", xsldbgText(termName)));
                 }
             } else {
                 xsldbgGenericErrorFunc(i18n("Error: Did not previously open terminal.\n"));
@@ -212,7 +201,7 @@ openTerminal(xmlChar * device)
                 termName = xmlMemStrdup((char *) device);
                 result = 1;
             } else {
-                xsldbgGenericErrorFunc(i18n("Error: Unable to open terminal %1.\n").arg((char*)device));
+                xsldbgGenericErrorFunc(i18n("Error: Unable to open terminal %1.\n", xsldbgText(device)));
             }
 
     }
@@ -221,18 +210,7 @@ openTerminal(xmlChar * device)
 }
 
 
-/**
- * guessStylesheetHelper:
- * @payload: valid xsltStylesheetPtr
- * @data: valid searchInfoPtr of type SEARCH_NODE
- * @name: not used
- *
- * Try to guess what the complete file/URI is. If successful the search
- *   info will be set to found and the search data will contain the
- *   file name found. We are given our payload via walkStylesheets
- */
-void
-guessStylesheetHelper(void *payload, void *data,
+void guessStylesheetHelper(void *payload, void *data,
                       xmlChar * name)
 {
     Q_UNUSED(name);
@@ -263,8 +241,8 @@ guessStylesheetHelper(void *payload, void *data,
         /* try to guess we assume that the files are unique */
         xmlStrCpy(filesBuffer, "__#!__");
         /* try relative to top stylesheet directory */
-        if (stylePath()) {
-            xmlStrCpy(filesBuffer, stylePath());
+        if (!stylePath().isEmpty()) {
+            xmlStrCpy(filesBuffer, stylePath().toUtf8().constData());
             xmlStrCat(filesBuffer, searchData->nameInput);
         }
         if (xmlStrCmp(style->doc->URL, filesBuffer) == 0) {
@@ -276,9 +254,9 @@ guessStylesheetHelper(void *payload, void *data,
             return;
         }
 
-        if (workingPath()) {
+        if (!workingPath().isEmpty()) {
             /* try relative to working directory */
-            xmlStrCpy(filesBuffer, workingPath());
+            xmlStrCpy(filesBuffer, workingPath().toUtf8().constData());
             xmlStrCat(filesBuffer, searchData->nameInput);
         }
         if (xmlStrCmp(style->doc->URL, filesBuffer) == 0) {
@@ -312,18 +290,7 @@ guessStylesheetHelper(void *payload, void *data,
 }
 
 
-/**
- * guessStylesheetHelper2:
- * @payload: valid xmlNodePtr of the included stylesheet 
- * @data: valid searchInfoPtr of type SEARCH_NODE
- * @name: not used
- *
- * Try to guess what the complete file/URI is. If successful the search
- *   info will be set to found and the search data will contain the
- *   file name found. We are given our payload via walkIncludes
- */
-void
-guessStylesheetHelper2(void *payload, void *data,
+void guessStylesheetHelper2(void *payload, void *data,
                        xmlChar * name)
 {
     Q_UNUSED(name);
@@ -354,8 +321,8 @@ guessStylesheetHelper2(void *payload, void *data,
         /* try to guess we assume that the files are unique */
         xmlStrCpy(filesBuffer, "__#!__");
         /* try relative to top stylesheet directory */
-        if (stylePath()) {
-            xmlStrCpy(filesBuffer, stylePath());
+        if (!stylePath().isEmpty()) {
+            xmlStrCpy(filesBuffer, stylePath().toUtf8().constData());
             xmlStrCat(filesBuffer, searchData->nameInput);
         }
         if (xmlStrCmp(node->doc->URL, filesBuffer) == 0) {
@@ -367,9 +334,9 @@ guessStylesheetHelper2(void *payload, void *data,
             return;
         }
 
-        if (workingPath()) {
+        if (!workingPath().isEmpty()) {
             /* try relative to working directory */
-            xmlStrCpy(filesBuffer, workingPath());
+            xmlStrCpy(filesBuffer, workingPath().toUtf8().constData());
             xmlStrCat(filesBuffer, searchData->nameInput);
         }
         if (xmlStrCmp(node->doc->URL, filesBuffer) == 0) {
@@ -403,15 +370,7 @@ guessStylesheetHelper2(void *payload, void *data,
 }
 
 
-/**
- * guessStylesheetName:
- * @searchInf: Is valid
- *
- * Try to find a matching stylesheet name
- * Sets the values in @searchinf depending on outcome of search
- */
-void
-guessStylesheetName(searchInfoPtr searchCriteria)
+void guessStylesheetName(searchInfoPtr searchCriteria)
 {
     nodeSearchDataPtr searchData;
 
@@ -432,56 +391,27 @@ guessStylesheetName(searchInfoPtr searchCriteria)
 }
 
 
-/**
- * stylePath:
- *
- * Return The base path for the top stylesheet ie
- *        ie URL minus the actual file name
- *
- * Returns The base path for the top stylesheet ie
- *        ie URL minus the actual file name
- */
-xmlChar *
-stylePath(void)
+QString stylePath(void)
 {
     return stylePathName;
 }
 
 
-/**
- * workingPath:
- * 
- * Return the working directory as set by changeDir function
- *
- * Returns The working directory as set by changeDir function
- */
-xmlChar *
-workingPath(void)
+QString workingPath(void)
 {
     return workingDirPath;
 }
 
 
-/**
- * changeDir:
- * @path: The path to adopt as new working directory
- *
- * Change working directory to path 
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-changeDir(const xmlChar * path)
+int changeDir(QString path)
 {
     int result = 0;
-    int charIndex;
-    const char endString[2] = { PATHCHAR, '\0' };
-    xmlChar *expandedName = NULL;
+    QString expandedName;
 
 
-    if (path && (xmlStrLen(path) > 0)) {
-        expandedName = filesExpandName(path);
+    if (!path.isEmpty()) {
+        // expand the path but do not add the "file:// prefix"
+        expandedName = filesExpandName(path, false);
     } else {
 #ifdef WITH_XSLDBG_DEBUG_PROCESS
         xsltGenericError(xsltGenericErrorContext,
@@ -490,55 +420,33 @@ changeDir(const xmlChar * path)
         return result;
     }
 
-    if (!expandedName)
-        return result;          /* out of memory ? */
-
-    if (xmlStrLen(expandedName) + 1 > sizeof(filesBuffer)) {
-        xsldbgGenericErrorFunc(i18n("Error: The file name \"%1\" is too long.\n").arg((char*)path));
+    if (expandedName.isEmpty()){
+        xsldbgGenericErrorFunc(i18n("Error: Unable to change to directory %1.\n", path));
         return result;
     }
 
-    xmlStrCpy(filesBuffer, expandedName);
-    /* strip off any extra PATHCHAR's as win32's chdir function 
-     * fails if we don't */
-    charIndex = xmlStrLen(filesBuffer) - 1;
-    while (charIndex && (filesBuffer[charIndex] == PATHCHAR)) {
-        charIndex--;
-    }
-    filesBuffer[charIndex + 1] = '\0';
+    QDir d;
+    QString newDir(expandedName);
 
-
-    if (chdir((char *) filesBuffer) == 0) {
-        if (workingDirPath)
-            xmlFree(workingDirPath);
+    if (d.cd(newDir) && ::chdir(QFile::encodeName(newDir)) == 0) {
+        newDir = QDir::currentPath();
         /* must have path char at end of path name */
-        xmlStrCat(filesBuffer, endString);
-        workingDirPath = (xmlChar *) xmlMemStrdup((char *) filesBuffer);
+        workingDirPath = newDir + PATHCHAR;
+        optionsSetStringOption(OPTIONS_CWD, workingDirPath);
         result = 1;
     }
-    xmlFree(expandedName);      /* this will always be valid time */
     if (!result) {
-        xsldbgGenericErrorFunc(i18n("Error: Unable to change to directory %1.\n").arg((char*)path));
+        xsldbgGenericErrorFunc(i18n("Error: Unable to change to directory %1.\n", path));
     } else {
+
 	if (xslDebugStatus != DEBUG_NONE)
-	    xsldbgGenericErrorFunc(i18n("Changed to directory %1.\n").arg((char*)path));
+	    xsldbgGenericErrorFunc(i18n("Changed to directory %1.\n", workingDirPath));
     }
     return result;
 }
 
 
-/**
- * filesLoadXmlFile:
- * @path: xml file to load
- * @fileType: A valid FileTypeEnum 
- * 
- * Load specified file type, freeing any memory previously used 
- *
- * Returns 1 on success,
- *         0 otherwise 
- */
-int
-filesLoadXmlFile(const xmlChar * path, FileTypeEnum fileType)
+int filesLoadXmlFile(const xmlChar * path, FileTypeEnum fileType)
 {
     int result = 0;
 
@@ -549,9 +457,9 @@ filesLoadXmlFile(const xmlChar * path, FileTypeEnum fileType)
         case FILES_XMLFILE_TYPE:
             if (path && xmlStrLen(path)) {
                 if (optionsGetIntOption(OPTIONS_SHELL)) {
-                    xsldbgGenericErrorFunc(i18n("Setting XML Data file name to %1.\n").arg((char*)path));
+                    xsldbgGenericErrorFunc(i18n("Setting XML Data file name to %1.\n", xsldbgText(path)));
                 }
-                optionsSetStringOption(OPTIONS_DATA_FILE_NAME, path);
+                optionsSetStringOption(OPTIONS_DATA_FILE_NAME, xsldbgText(path));
             }
             topDocument = xsldbgLoadXmlData();
             if (topDocument)
@@ -561,30 +469,25 @@ filesLoadXmlFile(const xmlChar * path, FileTypeEnum fileType)
         case FILES_SOURCEFILE_TYPE:
             if (path && xmlStrLen(path)) {
                 if (optionsGetIntOption(OPTIONS_SHELL)) {
-                    xsldbgGenericErrorFunc(i18n("Setting stylesheet file name to %1.\n").arg((char*)path));
+                    xsldbgGenericErrorFunc(i18n("Setting stylesheet file name to %1.\n", xsldbgText(path)));
                 }
-                optionsSetStringOption(OPTIONS_SOURCE_FILE_NAME, path);
+                optionsSetStringOption(OPTIONS_SOURCE_FILE_NAME, xsldbgText(path));
             }
             topStylesheet = xsldbgLoadStylesheet();
             if (topStylesheet && topStylesheet->doc) {
                 /* look for last slash (or baskslash) of URL */
-                char *lastSlash = xmlStrrChr(topStylesheet->doc->URL,
-                                             PATHCHAR);
-                const char *docUrl =
-                    (const char *) topStylesheet->doc->URL;
+                QString docUrl = xsldbgText(topStylesheet->doc->URL);
+                int lastSlash = docUrl.lastIndexOf(PATHCHAR);
 
                 result = 1;
-                if (docUrl && lastSlash) {
-                    stylePathName = (xmlChar *) xmlMemStrdup(docUrl);
-                    stylePathName[lastSlash - docUrl + 1] = '\0';
+                if (!docUrl.isEmpty() && lastSlash) {
+                    stylePathName = docUrl.mid(0, lastSlash);
                     if (optionsGetIntOption(OPTIONS_SHELL)) {
-                        xsldbgGenericErrorFunc(i18n("Setting stylesheet base path to %1.\n").arg((char*)stylePathName));
+                        xsldbgGenericErrorFunc(i18n("Setting stylesheet base path to %1.\n", stylePathName));
                     }
                 } else {
-                    const char cwd[4] = { '.', PATHCHAR, '\0' };
-
                     /* ie for *nix this becomes "./" */
-                    stylePathName = xmlStrdup(BAD_CAST cwd);
+                    stylePathName = '.' + PATHCHAR;
                 }
 
                 /* try to find encoding for this stylesheet */
@@ -607,17 +510,7 @@ filesLoadXmlFile(const xmlChar * path, FileTypeEnum fileType)
 }
 
 
-/**
- * filesFreeXmlFile:
- * @fileType: A valid FileTypeEnum 
- * 
- * Free memory associated with the xml file 
- *
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-filesFreeXmlFile(FileTypeEnum fileType)
+int filesFreeXmlFile(FileTypeEnum fileType)
 {
     int result = 0, type = fileType;
 
@@ -632,9 +525,6 @@ filesFreeXmlFile(FileTypeEnum fileType)
         case FILES_SOURCEFILE_TYPE:
             if (topStylesheet)
                 xsltFreeStylesheet(topStylesheet);
-            if (stylePathName)
-                xmlFree(stylePathName);
-            stylePathName = NULL;
             topStylesheet = NULL;
             result = 1;
             break;
@@ -650,60 +540,25 @@ filesFreeXmlFile(FileTypeEnum fileType)
 }
 
 
-/**
- * filesGetStylesheet:
- *
- * Return The topmost stylesheet non-null on success,
- *         NULL otherwise
- *
- * Returns The topmost stylesheet non-null on success,
- *         NULL otherwise
- */
-xsltStylesheetPtr
-filesGetStylesheet(void)
+xsltStylesheetPtr filesGetStylesheet(void)
 {
     return topStylesheet;
 }
 
 
-/**
- * filesGetTemporaryDoc:
- *
- * Return The current "temporary" document
- *
- * Returns The current "temporary" document
- */
-xmlDocPtr
-filesGetTemporaryDoc(void)
+xmlDocPtr filesGetTemporaryDoc(void)
 {
     return tempDocument;
 }
 
 
-/**
- * filesGetMainDoc:
- *
- * Return The main docment
- *
- * Returns The main docment
- */
-xmlDocPtr
-filesGetMainDoc(void)
+xmlDocPtr filesGetMainDoc(void)
 {
     return topDocument;
 }
 
 
-/**
- * filesReloaded:
- * @reloaded: if = -1 then ignore @reloaded
- *             otherwise change the status of files to value of @reloaded   
- *
- * Returns 1 if stylesheet or its xml data file has been "flaged" as reloaded,
- *         0 otherwise
- */
-int
-filesReloaded(int reloaded)
+int filesReloaded(int reloaded)
 {
     static int changed = 0;
 
@@ -716,15 +571,7 @@ filesReloaded(int reloaded)
 
 
 
-/**
- * filesInit:
- *
- * Initialize the file related structures
- * Returns 1 on success,
- *         0 otherwise
- */
-int
-filesInit(void)
+int filesInit(void)
 {
     int result = 0;
 
@@ -759,13 +606,7 @@ filesInit(void)
     return result;
 }
 
-/**
- * filesFree:
- *
- * Free memory used by file related structures
- */
-void
-filesFree(void)
+void filesFree(void)
 {
     int result;
 
@@ -789,15 +630,6 @@ filesFree(void)
                          "Error: Unable to free memory used by XML/XSLT files\n");
 #endif
     }
-    if (stylePathName) {
-        xmlFree(stylePathName);
-        stylePathName = NULL;
-    }
-
-    if (workingDirPath) {
-        xmlFree(workingDirPath);
-        workingDirPath = NULL;
-    }
 
     if (entityNameList) {
         arrayListFree(entityNameList);
@@ -807,29 +639,25 @@ filesFree(void)
     /* Free memory used by encoding related structures */
     if (encodeInBuff)
         xmlBufferFree(encodeInBuff);
+    encodeInBuff = 0;
 
     if (encodeOutBuff)
         xmlBufferFree(encodeOutBuff);
+    encodeOutBuff = 0;
 
     /* close current encoding */
     filesSetEncoding(NULL);
 
     if (currentUrl)
         xmlFree(currentUrl);
+    currentUrl = 0;
 
     /* free any memory used by platform specific files module */
     filesPlatformFree();
 }
 
 
-/**
- * filesIsSourceFile:
- * @fileName : is valid
- * 
- * Returns true if @name has the ".xsl" externsion
- */
-int
-filesIsSourceFile(xmlChar * fileName)
+int filesIsSourceFile(xmlChar * fileName)
 {
     return strstr((char *) fileName, ".xsl") ||
         strstr((char *) fileName, ".Xsl") ||
@@ -838,8 +666,7 @@ filesIsSourceFile(xmlChar * fileName)
 
 
 
-entityInfoPtr
-filesNewEntityInfo(const xmlChar * SystemID, const xmlChar * PublicID)
+entityInfoPtr filesNewEntityInfo(const xmlChar * SystemID, const xmlChar * PublicID)
 {
 
     entityInfoPtr result = (entityInfoPtr) xmlMalloc(sizeof(entityInfo));
@@ -858,8 +685,7 @@ filesNewEntityInfo(const xmlChar * SystemID, const xmlChar * PublicID)
     return result;
 }
 
-void
-filesFreeEntityInfo(entityInfoPtr info)
+void filesFreeEntityInfo(entityInfoPtr info)
 {
     if (!info)
         return;
@@ -872,16 +698,7 @@ filesFreeEntityInfo(entityInfoPtr info)
     xmlFree(info);
 }
 
-/**
- * filesAddEntityName:
- * @name : is valid
- *
- * Add name to entity name list of know external entities if 
- *  it does not already exist in list
- */
-void
-
-filesAddEntityName(const xmlChar * SystemID, const xmlChar * PublicID)
+void filesAddEntityName(const xmlChar * SystemID, const xmlChar * PublicID)
 {
     int entityIndex = 0;
     entityInfoPtr tempItem;
@@ -905,17 +722,7 @@ filesAddEntityName(const xmlChar * SystemID, const xmlChar * PublicID)
 }
 
 
-/**
- * filesEntityRef :
- * @ent : Is valid as provided by libxslt
- * @firstNode : Is valid
- * @lastNode : Is Valid
- *
- * Fixes the nodes from firstNode to lastNode so that debugging can occur
-   */
-void
-
-filesEntityRef(xmlEntityPtr ent, xmlNodePtr firstNode, xmlNodePtr lastNode)
+void filesEntityRef(xmlEntityPtr ent, xmlNodePtr firstNode, xmlNodePtr lastNode)
 {
     xmlNodePtr node = firstNode;
     if (!firstNode || !ent || !ent->SystemID ||
@@ -937,20 +744,8 @@ filesEntityRef(xmlEntityPtr ent, xmlNodePtr firstNode, xmlNodePtr lastNode)
 
 
 
- /**
-   * filesSetBaseUri:
-   * @node : Is valid and has a doc parent
-   * @uri : Is Valid
-   * 
-   * Set the base uri for this node. Function is used when xml file
-   *    has external entities in its DTD
-   * 
-   * Returns 1 if successful,
-   *        0 otherwise
-   */
 
-int
-filesSetBaseUri(xmlNodePtr node, const xmlChar * uri)
+int filesSetBaseUri(xmlNodePtr node, const xmlChar * uri)
 {
     int result = 0;
 
@@ -970,18 +765,7 @@ filesSetBaseUri(xmlNodePtr node, const xmlChar * uri)
 }
 
 
-  /**
-   * filesGetBaseUri:
-   * @node : Is valid and has a doc parent
-   * 
-   * Get a copy of the base uri for this node. Function is most usefull 
-   *  used when xml file  has external entities in its DTD
-   * 
-   * Returns the a copy of the base uri for this node,
-   *         NULL otherwise
-   */
-xmlChar *
-filesGetBaseUri(xmlNodePtr node)
+xmlChar * filesGetBaseUri(xmlNodePtr node)
 {
     xmlChar *result = NULL;
 
@@ -1009,38 +793,20 @@ filesGetBaseUri(xmlNodePtr node)
 
 
 
-/**
- * filesEntityList:
- *
- * Return the list entity names used for documents loaded
- *
- * Returns the list entity names used for documents loaded
- */
-arrayListPtr
-filesEntityList(void)
+arrayListPtr filesEntityList(void)
 {
     return entityNameList;
 }
 
-extern int intVolitileOptions[OPTIONS_LAST_INT_OPTIONID - OPTIONS_FIRST_INT_OPTIONID + 1];
 
-/**
- * filesLoadCatalogs:
- *
- * Load the catalogs specifed by OPTIONS_CATALOG_NAMES if 
- *      OPTIONS_CATALOGS is enabled
- * Returns 1 if sucessful
- *         0 otherwise   
- */
-int
-filesLoadCatalogs(void)
+int filesLoadCatalogs(void)
 {
     int result = 0;
-    const char *catalogs = NULL;
+    QString catalogs;
 
     xmlCatalogCleanup();
     if (optionsGetIntOption(OPTIONS_CATALOGS)) {
-      if (optionsGetStringOption(OPTIONS_CATALOG_NAMES) == NULL) {
+      if (optionsGetStringOption(OPTIONS_CATALOG_NAMES).isEmpty()) {
 	/* use the SGML catalog */
 #ifdef __riscos
 	catalogs = getenv("SGML$CatalogFiles");
@@ -1055,19 +821,17 @@ filesLoadCatalogs(void)
 #endif
 	} else
 	  /* copy the current catalog name(s) for user to see */
-	  optionsSetStringOption(OPTIONS_CATALOG_NAMES,
-				 (xmlChar *) catalogs);
+	  optionsSetStringOption(OPTIONS_CATALOG_NAMES, catalogs);
       } else
 	/* Use the current catalog settings from users*/
-	catalogs = (char *)
-	  optionsGetStringOption(OPTIONS_CATALOG_NAMES);
+	catalogs = optionsGetStringOption(OPTIONS_CATALOG_NAMES);
 
       result = 1;
     }
 
-    if (catalogs){
+    if (!catalogs.isEmpty()){
       /* Load the new cataog selection */
-      xmlLoadCatalogs(catalogs);
+      xmlLoadCatalogs(catalogs.toUtf8().constData());
     }else{
       /* Use default catalogs */
       xmlInitializeCatalog();
@@ -1078,16 +842,7 @@ filesLoadCatalogs(void)
 
 
 
-  /**
-   * filesEncode:
-   * @text: Is valid, text to translate from UTF-8, 
-   *
-   * Return  A  new string of converted @text
-   *
-   * Returns  A  new string of converted @text, may be NULL
-   */
-xmlChar *
-filesEncode(const xmlChar * text)
+xmlChar * filesEncode(const xmlChar * text)
 {
     xmlChar *result = NULL;
 
@@ -1113,16 +868,7 @@ filesEncode(const xmlChar * text)
 
 
 
-  /**
-   * filesDeccode:
-   * @text: Is valid, text to translate from current encoding to UTF-8, 
-   *
-   * Return  A  string of converted @text
-   *
-   * Returns  A  string of converted @text, may be NULL
-   */
-xmlChar *
-filesDecode(const xmlChar * text)
+xmlChar * filesDecode(const xmlChar * text)
 {
     xmlChar *result = NULL;
 
@@ -1147,19 +893,7 @@ filesDecode(const xmlChar * text)
 }
 
 
-    /*
-     * filesSetEncoding:
-     * @encoding : Is a valid encoding supported by the iconv library or NULL
-     *
-     * Opens encoding for all standard output to @encoding. If  @encoding 
-     *        is NULL then close current encoding and use UTF-8 as output encoding
-     *
-     * Returns 1 if successful in setting the encoding of all standard output
-     *           to @encoding
-     *         0 otherwise
-     */
-int
-filesSetEncoding(const char *encoding)
+int filesSetEncoding(const char *encoding)
 {
     int result = 0;
 
@@ -1176,12 +910,11 @@ filesSetEncoding(const char *encoding)
             if (!result) {
                 xmlCharEncCloseFunc(stdoutEncoding);
                 stdoutEncoding = NULL;
-                xsldbgGenericErrorFunc(i18n("Unable to initialize encoding %1.").arg((char*)encoding));
+                xsldbgGenericErrorFunc(i18n("Unable to initialize encoding %1.", xsldbgText(encoding)));
             } else
-                optionsSetStringOption(OPTIONS_ENCODING,
-                                       (xmlChar *) encoding);
+                optionsSetStringOption(OPTIONS_ENCODING, xsldbgText(encoding));
         } else {
-            xsldbgGenericErrorFunc(i18n("Invalid encoding %1.\n").arg((char*)encoding));
+            xsldbgGenericErrorFunc(i18n("Invalid encoding %1.\n", xsldbgText(encoding)));
         }
     } else {
         /* close encoding and use UTF-8 */
@@ -1196,23 +929,7 @@ filesSetEncoding(const char *encoding)
 
 
 
-  /**
-   * filesMoreFile:
-   * @fileName : May be NULL
-   * @file : May be NULL
-   *
-   * Do a "more" like print of file specified by @fileName OR
-   *   @file. If both are provided @file will be used. The content 
-   *   of file chosen must be in UTF-8, and will be  printed in 
-   *   the current encoding selected.The function will pause output 
-   *   after FILES_NO_LINES lines have been printed waiting for
-   *   user to enter "q" to quit or any other text to continue.
-   *
-   * Returns 1 if successful,
-   *         0 otherwise
-   */
-int
-filesMoreFile(const xmlChar * fileName, FILE * file)
+int filesMoreFile(const xmlChar * fileName, FILE * file)
 {
     int result = 0;
     int openedFile = 0;
@@ -1270,19 +987,11 @@ filesMoreFile(const xmlChar * fileName, FILE * file)
 }
 
 
-  /**
-   * filesSearchResultsPath:
-   *
-   * Get the base path to be used for storing search results
-   *
-   * Returns The base path to be used for storing search results
-   */
-const xmlChar *
-filesSearchResultsPath()
+QString filesSearchResultsPath()
 {
-    const xmlChar *result;
+    QString result;
 
-    if (optionsGetStringOption(OPTIONS_SEARCH_RESULTS_PATH))
+    if (!optionsGetStringOption(OPTIONS_SEARCH_RESULTS_PATH).isEmpty())
         result = optionsGetStringOption(OPTIONS_SEARCH_RESULTS_PATH);
     else
         result = stylePath();
@@ -1291,21 +1000,6 @@ filesSearchResultsPath()
 }
 
 
-  /**
-   * filesURItoFileName:
-   * @uri : A valid URI that uses the "file://" prefix
-   *
-   * Return A copy of the conversion of @uri to a file name
-   *        that is suitable to be used  with the fopen function.
-   *        May be NULL, if out of memory, @uri does not use the
-   *        "file://" prefix, or unable to convert to a valid file name
-   *
-   * Returns A copy of the conversion of @uri to a file name
-   *        that is suitable to be used with the fopen function.
-   *        May be NULL, if out of memory, @uri does not use the
-   *        "file://" prefix, or unable to convert to a valid file name
-   *    
-   */
 xmlChar *filesURItoFileName(const xmlChar* uri)
 {
   xmlChar *result = NULL;
@@ -1320,8 +1014,10 @@ xmlChar *filesURItoFileName(const xmlChar* uri)
       if (!xmlStrnCmp(uri, "file:///", 8))
 	tempName = uri + 8;
 #else
-      if (!xmlStrnCmp(uri, "file://", 7))
-	tempName = uri + 6; /* we need the leading '/'*/
+      if (!xmlStrnCmp(uri, "file:/", 6))
+	tempName = uri + 5; //  we need the leading '/'*/
+        while (tempName[0] == '/' && tempName[1] == '/' ) 
+            tempName++;
 #endif
     }
 
@@ -1358,7 +1054,7 @@ xmlChar *filesURItoFileName(const xmlChar* uri)
 	result = NULL;
       }
     }else{
-        xsldbgGenericErrorFunc(i18n("Error: Unable to convert %1 to local file name.\n").arg((char*)uri));
+        xsldbgGenericErrorFunc(i18n("Error: Unable to convert %1 to local file name.\n", xsldbgText(uri)));
     }
 
 
@@ -1368,17 +1064,9 @@ xmlChar *filesURItoFileName(const xmlChar* uri)
 
 /* TODO in xsldbg 3.x rename these to use files prefix */
 
-/**
- * xsldbgUpdateFileDetails:
- * @node : A valid node
- * 
- * Update the URL and  line number that we stoped at 
- */
-void
-xsldbgUpdateFileDetails(xmlNodePtr node)
+void xsldbgUpdateFileDetails(xmlNodePtr node)
 {
-    if ((node != NULL) && (node->doc != NULL)
-        && (node->doc->URL != NULL)) {
+    if ((node != NULL) && (node->doc != NULL)) {
         if (currentUrl != NULL)
             xmlFree(currentUrl);
         currentUrl =  filesGetBaseUri(node);
@@ -1387,30 +1075,13 @@ xsldbgUpdateFileDetails(xmlNodePtr node)
 }
 
 
-/**
- * xsldbgLineNo:
- *
- * What line number are we at 
- *
- * Returns The current line number of xsldbg, may be -1
- **/
-int
-xsldbgLineNo(void)
+int xsldbgLineNo(void)
 {
     return currentLineNo;
 }
 
 
-/**
- * xsldbgUrl:
- * 
- * What URL did we stop at
- *
- * Returns A NEW copy of URL stopped at. Caller must free memory for URL.
- *  May be NULL  
- */
-xmlChar *
-xsldbgUrl(void)
+xmlChar * xsldbgUrl(void)
 {
     if (currentUrl != NULL)
         return (xmlChar *) xmlMemStrdup((char *) currentUrl);
